@@ -95,6 +95,7 @@ class DjangoReadEditSwitchAdmin(BaseModelAdmin):
             ]
         }
         js = [
-            "jquery3/jquery.js",
+            "admin/js/vendor/jquery/jquery.js",
             "admin/js/django-readedit-switch-admin.js",
+            "admin/js/jquery.init.js",
         ]
